antares.apps.message.models package
===================================

Submodules
----------

antares.apps.message.models.message module
------------------------------------------

.. automodule:: antares.apps.message.models.message
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.message.models.message\_status module
--------------------------------------------------

.. automodule:: antares.apps.message.models.message_status
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.message.models
   :members:
   :undoc-members:
   :show-inheritance:
